[![License: LGPL v3](https://img.shields.io/badge/License-LGPLv3-blue.svg)](https://www.gnu.org/licenses/lgpl-3.0)
[![codecov](https://codecov.io/gh/qpv-research-group/rayflare/branch/devel/graph/badge.svg)](https://codecov.io/gh/qpv-research-group/rayflare)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/7ff9180e5f7a460192440895d823ff15)](https://www.codacy.com/gh/qpv-research-group/rayflare?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=qpv-research-group/rayflare&amp;utm_campaign=Badge_Grade)
[![Documentation Status](https://readthedocs.org/projects/rayflare/badge/?version=latest)](https://rayflare.readthedocs.io/en/latest/?badge=latest)
[![status](https://joss.theoj.org/papers/15647ef7b3dd688b47c1b802a4f50a67/status.svg)](https://joss.theoj.org/papers/15647ef7b3dd688b47c1b802a4f50a67)

**Important**: Please check out the [news & updates](https://rayflare.readthedocs.io/en/latest/news.html) page for the most recent updates
and changes, including any possible backwards compatibility issues.  If you have questions, issues, etc., please check the
documentation and (open and closed) [issues](https://github.com/qpv-research-group/rayflare/issues) first,
or open a new issue using the relevant template.

# rayflare
Open-source, integrated optical modelling of complex stacks. RayFlare incorporates the transfer-matrix method (TMM), 
ray-tracing and rigorous coupled-wave analysis (RCWA/FMM), in addition to an angular redistribution matrix method which allows multiple 
methods to be coupled across a single structure to calculate total absorption/reflection/transmission, absorption per 
layer, and absorption profiles. 

You can view RayFlare's documentation, including installation instructions [here](https://rayflare.readthedocs.io/en/latest/).
The contributing guidelines are [here](CONTRIBUTING.md) and the Code of Conduct is [here](CODE_OF_CONDUCT.md). This package
is distributed under a [GNU LGPL (version 3) license](GNU_LGPL_v3.txt). If you have questions, issues, etc., please check the
documentation first or open an [issue](https://github.com/qpv-research-group/rayflare/issues) using the relevant template.

If you use RayFlare in your work, please cite the [JOSS paper](https://doi.org/10.21105/joss.03460):

*Pearce, P. M., (2021). RayFlare: flexible optical modelling of solar cells. Journal of Open Source Software, 6(65), 3460. 
https://doi.org/10.21105/joss.03460*

![poster](poster.png "RayFlare poster")
